"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _X = _interopRequireDefault(require("./X"));

var _Y = _interopRequireDefault(require("./Y"));

var _PlotWrapper = _interopRequireDefault(require("./PlotWrapper"));

var _ChartTime = _interopRequireDefault(require("./ChartTime"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const ChartFrame = ({
  config,
  data,
  timeKey
}) => {
  const chartFrame = (0, _react.useRef)(null);
  const [chartWidth, setChartWidth] = (0, _react.useState)(null);
  const {
    x,
    y,
    chartHeight = 480,
    chartFrameStyle = {},
    chartTimeVisible = true,
    chartTimeStyle = {},
    axisColor = '#333',
    onChartDidMount = () => {},
    onChartDidUpdate = () => {}
  } = config; // Error handling

  if (!x || !y) {
    console.error('Parameter x and y are required.');
    return '';
  }

  if (typeof x.min !== 'number' || typeof x.max !== 'number' || typeof x.interval !== 'number' || typeof y.min !== 'number' || typeof y.max !== 'number' || typeof y.interval !== 'number') {
    console.error('Parameter min, max and interval for both x and y are required.');
    return '';
  }

  (0, _react.useEffect)(() => {
    // for the first time only
    setChartWidth(chartFrame.current.clientWidth);
    window.addEventListener('resize', () => setChartWidth(chartFrame.current.clientWidth));
    onChartDidMount(chartFrame.current, timeKey);
  }, []);
  (0, _react.useEffect)(() => {
    if (!chartWidth) return;
    onChartDidUpdate(chartFrame.current, timeKey);
  });
  const style = {
    position: 'relative',
    width: '100%',
    maxWidth: `${config.chartWidth ? `${config.chartWidth}px` : '100%'}`,
    height: `${chartHeight}px`,
    marginLeft: 'auto',
    marginRight: 'auto',
    ...chartFrameStyle
  };
  return _react.default.createElement(_react.Fragment, null, _react.default.createElement("div", {
    className: 'factful-bubble-chart-frame',
    ref: chartFrame,
    style: style
  }, chartWidth && _react.default.createElement(_react.Fragment, null, chartTimeVisible && _react.default.createElement(_ChartTime.default, {
    chartTimeStyle: chartTimeStyle,
    timeKey: timeKey
  }), _react.default.createElement(_PlotWrapper.default, {
    chartWidth: chartWidth,
    chartHeight: chartHeight,
    config: config,
    data: data,
    timeKey: timeKey
  }), _react.default.createElement(_X.default, {
    x: x,
    axisColor: axisColor
  }), _react.default.createElement(_Y.default, {
    y: y,
    axisColor: axisColor
  }))));
};

var _default = ChartFrame;
exports.default = _default;