"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _Plot = _interopRequireDefault(require("./Plot"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const PlotWrapper = ({
  chartWidth,
  chartHeight,
  config,
  data,
  timeKey
}) => {
  const {
    x,
    y,
    maxPlotSize = 40,
    minPlotSize = 1.5,
    groupColor = {},
    onPlotMouseEnter = () => {},
    onPlotMouseLeave = () => {},
    onPlotClick = () => {}
  } = config;
  const ratioX = chartWidth / (x.max - x.min);
  const ratioY = chartHeight / (y.max - y.min);
  const xOffset = x.min * ratioX;
  const yOffset = y.max * ratioY; // data to be passed to child Plot component

  const processedData = data.map(datum => {
    if (!datum.content[String(timeKey)]) return;
    const {
      x,
      y,
      normalizedSize
    } = datum.content[String(timeKey)];
    const {
      name,
      group
    } = datum;
    return {
      data: {
        name,
        group,
        x,
        y,
        r: normalizedSize <= minPlotSize / maxPlotSize ? minPlotSize : normalizedSize * maxPlotSize,
        positionX: Math.round(ratioX * x - xOffset),
        positionY: -Math.round(ratioY * y - yOffset),
        groupColor: groupColor[group] ? groupColor[group] : {}
      },
      normalizedSize,
      onPlotMouseEnter,
      onPlotMouseLeave,
      onPlotClick
    };
  }); // ordered array of names that defines z-index of plots

  const orderedName = processedData.slice().sort((a, b) => {
    return b.normalizedSize - a.normalizedSize;
  }).map(data => data.data.name);
  return _react.default.createElement(_react.Fragment, null, _react.default.createElement("div", {
    style: {
      position: 'relative',
      width: '100%',
      height: '100%',
      zIndex: '2'
    }
  }, processedData.map(args => {
    if (!args) {
      console.error(`Data cannot be found. timeKey: ${timeKey}`);
      return;
    }

    return _react.default.createElement(_Plot.default, {
      key: args.data.name,
      data: args.data,
      zIndex: orderedName.indexOf(args.data.name),
      onPlotMouseEnter: args.onPlotMouseEnter,
      onPlotMouseLeave: args.onPlotMouseLeave,
      onPlotClick: args.onPlotClick
    });
  })));
};

var _default = PlotWrapper;
exports.default = _default;